Learn R Programming

contiBAIT (version 1.0.0)

barplotLinkageGroupCalls,LinkageGroupList,ChrTable-method: Bar plot all linkage groups, with the true chromosomes of contigs coloured.

Description

Bar plot all linkage groups, with the true chromosomes of contigs coloured.

Usage

## S3 method for class 'LinkageGroupList,ChrTable':
barplotLinkageGroupCalls(object, chrTable,
  by = "lg", returnTable = FALSE)

Arguments

object
LinkageGroupList, as generated by clusterContigs
chrTable
GRanges object containing assembly information about the contigs, including a meta column called 'name' that has names matching the object. Note that the rownames of chrTable should be the contig names, as they are used in object, and the first column (chromosome name) will used to order by chromosome if 'chr' option used in by parameter. To use a bam file header, the product of makeChrTable(bamFile) is suitable for input
by
whether to plot by linkage group (if 'lg') or chromosomes ('chr')
returnTable
TRUE to return chromosome length matrix. Note to include legend, use legend=rownames(chr.table) for by='lg', and legend=colnames(chr.table) for by='chr'

Value

  • a matrix of lengths of each chromosome (rows) in each linkage group (columns)

Examples

Run this code
data("exampleLGList")
data("exampleDividedChr")

barplotLinkageGroupCalls(exampleLGList, exampleDividedChr)

Run the code above in your browser using DataLab