Learn R Programming

contiBAIT (version 1.0.0)

mergeLinkageGroups,LinkageGroupList,StrandStateMatrix-method: mergeLinkageGroups -- merge very similar linkage groups, including those in reverse orientation

Description

mergeLinkageGroups -- merge very similar linkage groups, including those in reverse orientation

Usage

## S3 method for class 'LinkageGroupList,StrandStateMatrix':
mergeLinkageGroups(object,
  allStrands, clusterParam = NULL, cluster = 1, similarityCutoff = 0.7)

Arguments

object
LinkageGroupList
allStrands
StrandStateMatrix for all linkageGroups (usually reoriented by reorientStrandTable)
clusterParam
optional BiocParallelParam specifying cluster to use for parallel execution. When NULL, execution will be serial.
cluster
Integer denoting the number of reclusterings to be performed for creating linkage groups (default is 1)
similarityCutoff
merge contigs that are more similar this this

Value

  • list of indices within the allStrands matrix indicating linkage group membership, a list consisting of a strandStateMatrix (a reoriented version of allStrands), and a data.frame of type OrientationFrame containing contig names and orientations, as '+' or '-'.

Examples

Run this code
data(exampleWCMatrix)
clusteredContigs <- clusterContigs(exampleWCMatrix, randomise=FALSE)

reorientedMatrix <- reorientLinkageGroups(clusteredContigs,
										  exampleWCMatrix)

exampleLGList <- mergeLinkageGroups(clusteredContigs,
									reorientedMatrix[[1]])

Run the code above in your browser using DataLab