Learn R Programming

contiBAIT (version 1.0.0)

orderAllLinkageGroups,LinkageGroupList,StrandStateMatrix,StrandFreqMatrix,StrandReadMatrix-method: Function to call contig ordering algorithms iteratively across each linkage group element

Description

Function to call contig ordering algorithms iteratively across each linkage group element

Usage

## S3 method for class 'LinkageGroupList,StrandStateMatrix,StrandFreqMatrix,StrandReadMatrix':
orderAllLinkageGroups(linkageGroupList,
  strandStateMatrix, strandFreqMatrix, strandReadCount, whichLG = NULL,
  saveOrdered = FALSE, orderCall = "greedy", randomAttempts = 75,
  verbose = TRUE)

Arguments

linkageGroupList
list of vectors, each specifying which contigs belong in which linkage group (product of clusterContigs)
strandStateMatrix
table of strand calls for all contigs (product of preprocessStrandTable)
strandFreqMatrix
table of W:C read proportions (used for QC) (product of strandSeqFreqTable[[1]])
strandReadCount
table of read counts (product of strandSeqFreqTable[[2]])
whichLG
vector of integers specifying the element(s) of linkageGroupList to be ordered (i.e. which specific linkage groups to try to order). Default is all LGs.
saveOrdered
Will return a pdf of heatmaps for each linkage group; String entered becomes the fileName (default is saveOrderedPDF=FALSE)
orderCall
currently either 'greedy' for greedy algorithm or 'TSP' for travelling salesperson alogrithm (default is 'greedy')
randomAttempts
iterger specifying number of randomized clusterings to identify the best ordering. Default is 75
verbose
Pringts messages to the terminal. Default is TRUE

Value

  • a data.frame of ordered contigs with linkage group names

Examples

Run this code
#Get a data.frame of ordered contigs from cells from the same organism, aligned to the same genome
 
data("exampleLGList")
data("exampleWCMatrix")
data("exampleStrandFreq")
data("exampleReadCounts")
contigOrder <- orderAllLinkageGroups(exampleLGList, exampleWCMatrix, exampleStrandFreq, exampleReadCounts)

show(contigOrder)

Run the code above in your browser using DataLab