Learn R Programming

contiBAIT (version 1.0.0)

reorientLinkageGroups,LinkageGroupList,StrandStateMatrix-method: reorientLinkageGroups uses a simple dissimilarity to find misoriented fragments within linkage groups.

Description

reorientLinkageGroups uses a simple dissimilarity to find misoriented fragments within linkage groups.

Usage

## S3 method for class 'LinkageGroupList,StrandStateMatrix':
reorientLinkageGroups(object,
  allStrands, previousOrient = NULL, verbose = TRUE)

Arguments

object
List of vectors containing names of contigs belonging to each LG.
allStrands
Table of type strandStateMatrix encompassing strand state for all contigs. Product of StrandSeqFreqTable.
previousOrient
data.frame of type OrientationFrame of previous orientation states if performed. Default is NULL
verbose
Outputs information to the terminal. Default is TRUE.

Value

  • a list consisting of a strandStateMatrix (a reoriented version of allStrands), and a data.frame of type OrientationFrame containing contig names and orientations, as '+' or '-'.

Examples

Run this code
data(exampleWCMatrix)
clusteredContigs <- clusterContigs(exampleWCMatrix, randomise=FALSE)

reorientedMatrix <- reorientLinkageGroups(clusteredContigs,
										  exampleWCMatrix)

# Note that in this example data, everything is correctly oreiented to
# to begin with, so all contigs come out as + orientation

Run the code above in your browser using DataLab