chrTable
GRanges object containing assembly information about the contigs, including a meta column called 'name' that has names matching the object.
Note that the rownames of chrTable should be the contig names, as they are used in object, and the first column (chromosome name) will used to order by chromosome if 'chr' option used in by parameter.
To use a bam file header, the product of makeChrTable(bamFile) is suitable for input
returnTable
TRUE to return chromosome length matrix.
Note to include legend, use legend=rownames(chr.table) for by='lg', and legend=colnames(chr.table) for by='chr'